@@ -434,7 +434,7 @@ class measures(_measures):
         """
         if is_measure(rfq) and rfq['type'] == 'frequency':
             rfq = dq.quantity(rfq['m0'])
-        elif isinstance(rfq, str):
+        elif isinstance(rfq, string_types):
             rfq = dq.quantity(rfq)
         if is_measure(v0) and v0['type'] == 'doppler' \
                 and dq.is_quantity(rfq) \
@@ -486,7 +486,7 @@ class measures(_measures):
         """
         if is_measure(rfq) and rfq['type'] == 'frequency':
             rfq = dq.quantity(rfq['m0'])
-        elif isinstance(rfq, str):
+        elif isinstance(rfq, string_types):
             rfq = dq.quantity(rfq)
         if is_measure(v0):
             if v0['type'] == 'radialvelocity':
@@ -626,7 +626,7 @@ class measures(_measures):
         import re
         rx = re.compile("m\d+")
         out = []
-        keys = v.keys()[:]
+        keys = list(v.keys())
         keys.sort()
         for key in keys:
             if re.match(rx, key):
@@ -821,7 +821,7 @@ class measures(_measures):
         """
 
         a = self.rise(crd, ev)
-        if isinstance(a['rise'], str):
+        if isinstance(a['rise'], string_types):
             return {"rise": {"last": a[0], "utc": a[0]},
                     "set": {"last": a[1], "utc": a[1]},
                     "solved": False}
