@@ -25,11 +25,12 @@
 #
 # $Id: tableutil.py,v 1.6 2006/11/08 00:12:55 gvandiep Exp $
 
-from casacore.six import PY2
+from six import string_types, integer_types
 import numpy
 import re
 from ..quanta import quantity
 
+
 # A keywordset in a table can hold tables, but it is not possible to
 # pass them around because a ValueHolder cannot deal with it.
 # Therefore it is passed around as a string with a special prefix.
@@ -41,15 +42,15 @@ def _add_prefix(name):
 def _do_remove_prefix(name):
     """Strip the possible prefix 'Table: ' from a table name."""
     res = name
-    if isinstance(res, str):
-        if (res.find('Table: ') == 0):
+    if isinstance(res, string_types):
+        if res.find('Table: ') == 0:
             res = res.replace('Table: ', '', 1)
     return res
 
 
 def _remove_prefix(name):
     """Strip the possible prefix 'Table: ' from one or more table names."""
-    if isinstance(name, str):
+    if isinstance(name, string_types):
         return _do_remove_prefix(name)
     return [_do_remove_prefix(nm) for nm in name]
 
@@ -113,15 +114,13 @@ def _check_key_slice(key, nrows, name):
 def _value_type_name(value):
     if isinstance(value, bool):
         return 'boolean'
-    if isinstance(value, int):
-        return 'integer'
-    if PY2 and isinstance(value, long):
+    if isinstance(value, integer_types):
         return 'integer'
     if isinstance(value, float):
         return 'double'
     if isinstance(value, complex):
         return 'dcomplex'
-    if isinstance(value, str):
+    if isinstance(value, string_types):
         return 'string'
     if isinstance(value, dict):
         return 'record'
@@ -138,11 +137,11 @@ def _format_date(val, unit):
     >>> _format_date(4914741782.503475, 's')
     "14-Aug-2014/14:03:03"
     """
-    if val==numpy.floor(val) and unit=='d':
+    if val == numpy.floor(val) and unit == 'd':
         # Do not show time part if 0
-        return quantity(val,unit).formatted('YMD_ONLY')
+        return quantity(val, unit).formatted('YMD_ONLY')
     else:
-        return quantity(val,unit).formatted('DMY')
+        return quantity(val, unit).formatted('DMY')
 
 
 def _format_quantum(val, unit):
@@ -157,9 +156,9 @@ def _format_quantum(val, unit):
     >>> _format_quantum(4914741782.503475, 's')
     "4.91474e+09 s"
     """
-    q=quantity(val,unit)
-    if q.canonical().get_unit() in ['rad','s']:
-        return quantity(val, 'm').formatted()[:-1]+unit
+    q = quantity(val, unit)
+    if q.canonical().get_unit() in ['rad', 's']:
+        return quantity(val, 'm').formatted()[:-1] + unit
     else:
         return q.formatted()
 
@@ -171,75 +170,76 @@ def _format_cell(val, colkeywords):
     :param colkeywords:
     :return: A HTML representation of this cell.
     """
-    out=""
+    out = ""
 
     # String arrays are returned as dict, undo that for printing
     if isinstance(val, dict):
-        tmpdict=numpy.array(val['array'])
+        tmpdict = numpy.array(val['array'])
         tmpdict.reshape(val['shape'])
         # Leave out quotes around strings
-        numpy.set_printoptions(formatter={'all':lambda x: str(x)})
-        out+=numpy.array2string(tmpdict, separator=', ')
+        numpy.set_printoptions(formatter={'all': lambda x: str(x)})
+        out += numpy.array2string(tmpdict, separator=', ')
         # Revert previous numpy print options
         numpy.set_printoptions(formatter=None)
     else:
-        valtype='other'
+        valtype = 'other'
 
         # Check if the column unit is like 'm' or ['m','m','m']
-        singleUnit=('QuantumUnits' in colkeywords and
-                    (numpy.array(colkeywords['QuantumUnits'])==numpy.array(colkeywords['QuantumUnits'])[0]).all())
-        if colkeywords.get('MEASINFO',{}).get('type')=='epoch' and singleUnit:
+        singleUnit = ('QuantumUnits' in colkeywords and
+                      (numpy.array(colkeywords['QuantumUnits']) == numpy.array(colkeywords['QuantumUnits'])[0]).all())
+        if colkeywords.get('MEASINFO', {}).get('type') == 'epoch' and singleUnit:
             # Format a date/time. Use quanta for scalars, use numpy for array logic around it
             # (quanta does not support higher dimensional arrays)
-            valtype='epoch'
+            valtype = 'epoch'
             if isinstance(val, numpy.ndarray):
-                numpy.set_printoptions(formatter={'all':lambda x: _format_date(x,colkeywords['QuantumUnits'][0])})
-                out+=numpy.array2string(val,separator=', ')
+                numpy.set_printoptions(formatter={'all': lambda x: _format_date(x, colkeywords['QuantumUnits'][0])})
+                out += numpy.array2string(val, separator=', ')
                 numpy.set_printoptions(formatter=None)
             else:
-                out+=_format_date(val,colkeywords['QuantumUnits'][0])
-        elif colkeywords.get('MEASINFO',{}).get('type')=='direction' and singleUnit and val.shape==(1,2):
-                # Format one direction. TODO: extend to array of directions
-                valtype='direction'
-                out+="["
-                part=quantity(val[0,0],'rad').formatted("TIME",precision=9)
-                part=re.sub(r'(\d+):(\d+):(.*)',r'\1h\2m\3',part)
-                out+=part+", "
-                part=quantity(val[0,1],'rad').formatted("ANGLE",precision=9)
-                part=re.sub(r'(\d+)\.(\d+)\.(.*)',r'\1d\2m\3',part)
-                out+=part+"]"
+                out += _format_date(val, colkeywords['QuantumUnits'][0])
+        elif colkeywords.get('MEASINFO', {}).get('type') == 'direction' and singleUnit and val.shape == (1, 2):
+            # Format one direction. TODO: extend to array of directions
+            valtype = 'direction'
+            out += "["
+            part = quantity(val[0, 0], 'rad').formatted("TIME", precision=9)
+            part = re.sub(r'(\d+):(\d+):(.*)', r'\1h\2m\3', part)
+            out += part + ", "
+            part = quantity(val[0, 1], 'rad').formatted("ANGLE", precision=9)
+            part = re.sub(r'(\d+)\.(\d+)\.(.*)', r'\1d\2m\3', part)
+            out += part + "]"
         elif isinstance(val, numpy.ndarray) and singleUnit:
             # Format any array with units
-            valtype='quanta'
-            numpy.set_printoptions(formatter={'all':lambda x: _format_quantum(x, colkeywords['QuantumUnits'][0])})
-            out+=numpy.array2string(val,separator=', ')
+            valtype = 'quanta'
+            numpy.set_printoptions(formatter={'all': lambda x: _format_quantum(x, colkeywords['QuantumUnits'][0])})
+            out += numpy.array2string(val, separator=', ')
             numpy.set_printoptions(formatter=None)
         elif isinstance(val, numpy.ndarray):
-            valtype='other'
+            valtype = 'other'
             # Undo quotes around strings
-            numpy.set_printoptions(formatter={'all':lambda x: str(x)})
-            out+=numpy.array2string(val,separator=', ')
+            numpy.set_printoptions(formatter={'all': lambda x: str(x)})
+            out += numpy.array2string(val, separator=', ')
             numpy.set_printoptions(formatter=None)
         elif singleUnit:
-            valtype='onequantum'
-            out+=_format_quantum(val, colkeywords['QuantumUnits'][0])
+            valtype = 'onequantum'
+            out += _format_quantum(val, colkeywords['QuantumUnits'][0])
         else:
-            valtype='other'
-            out+=str(val)
+            valtype = 'other'
+            out += str(val)
 
-    if 'QuantumUnits' in colkeywords and valtype=='other':
+    if 'QuantumUnits' in colkeywords and valtype == 'other':
         # Print units if they haven't been taken care of
-        if not (numpy.array(colkeywords['QuantumUnits'])==numpy.array(colkeywords['QuantumUnits'])[0]).all():
+        if not (numpy.array(colkeywords['QuantumUnits']) == numpy.array(colkeywords['QuantumUnits'])[0]).all():
             # Multiple different units for element in an array.
             # For now, just print the units and let the user figure out what it means
-            out+=" "+str(colkeywords['QuantumUnits'])
+            out += " " + str(colkeywords['QuantumUnits'])
         else:
-            out+=" "+colkeywords['QuantumUnits'][0]
+            out += " " + colkeywords['QuantumUnits'][0]
 
     # Numpy sometimes adds double newlines, don't do that
-    out=out.replace('\n\n','\n')
+    out = out.replace('\n\n', '\n')
     return out
 
+
 def _format_row(row, colnames, tab):
     """
     Helper function for _repr_html. Formats one row.
@@ -248,12 +248,12 @@ def _format_row(row, colnames, tab):
     :param tab: table, used to get the column keywords
     :return: html-formatted row
     """
-    out=""
+    out = ""
 
-    out+="\n<tr>"
+    out += "\n<tr>"
     for colname in colnames:
-        out+="<td style='vertical-align:top; white-space:pre'>"
-        out+=_format_cell(row[colname], tab.getcolkeywords(colname))
-        out+="</td>\n"
-    out+="</tr>\n"
+        out += "<td style='vertical-align:top; white-space:pre'>"
+        out += _format_cell(row[colname], tab.getcolkeywords(colname))
+        out += "</td>\n"
+    out += "</tr>\n"
     return out
