@@ -22,9 +22,8 @@
 #                        National Radio Astronomy Observatory
 #                        520 Edgemont Road
 #                        Charlottesville, VA 22903-2475 USA
-#
-# $Id$
 
+from six import string_types
 import numpy as np
 
 __all__ = ['getlocals', 'getvariable', 'substitute']
@@ -267,7 +266,7 @@ def substitutevar(v):
 def substituteonevar(v):
     # A string needs to be enclosed in quotes.
     # A vector value is enclosed in square brackets and separated by commas.
-    if isinstance(v, str):
+    if isinstance(v, string_types):
         return substitutestring(v)
     # A numeric or boolean value is converted to a string.
     # A vector value is enclosed in square brackets and separated by commas.
